@@ -1,7 +1,7 @@
 import random 
 import pandas as pd
 import numpy as np
-#import DBDIpy as dbdi
+import DBDIpy as dbdi
 
 
 def test_plot_adducts():
@@ -10,14 +10,12 @@ def test_plot_adducts():
     testdata = pd.DataFrame(np.random.randint(100, 1000000, size = (100, 100)))
     
     
-    fig = plot_adducts(testID, testdata, metadata = None, transform = False)
+    fig = dbdi.plot_adducts(testID, testdata, metadata = None, transform = False)
     
     assert fig is not None
    
     
-    
-    
-    
+
     
     
 """    
@@ -32,4 +30,12 @@ def test_create_confusion_matrix_plot():
     assert fig is not None
     assert fig.get_axes()[0].get_xlabel() == "MS2DeepScore"
     assert fig.get_axes()[0].get_ylabel() == 'Tanimoto similarity'
+    
+    
+import pprint
+import sys
+pprint.pprint(sys.path) 
+    
+sys.path.append('.')
+
 """
\ No newline at end of file
